bayespy.inference.vmp.nodes.gaussian_markov_chain.SwitchingGaussianMarkovChainDistribution.__init__
===================================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. automethod:: SwitchingGaussianMarkovChainDistribution.__init__